@@ -11,6 +11,7 @@ from .sessionassertion import SessionAssertion
 from .sessionexists import SessionExists
 from .sessionrequired import SessionRequired
 from .subjectauthenticated import SubjectAuthenticated
+from .subjectclaimset import SubjectClaimSet
 from .subjectregistered import SubjectRegistered
 
 
@@ -20,5 +21,6 @@ __all__: list[str] = [
     'SessionExists',
     'SessionRequired',
     'SubjectAuthenticated',
+    'SubjectClaimSet',
     'SubjectRegistered'
 ]
\ No newline at end of file
