@@ -7,8 +7,10 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .session import SessionRepository
+from .subject import SubjectRepository
 
 
 __all__: list[str] = [
-    'SessionRepository'
+    'SessionRepository',
+    'SubjectRepository',
 ]
\ No newline at end of file
