@@ -7,10 +7,14 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .apiresource import APIResource
+from .principal import AuthenticatedSessionPrincipal
+from .sessionendpoint import SessionEndpoint
 from .sessionresource import SessionResource
 
 
 __all__: list[str] = [
+    'AuthenticatedSessionPrincipal',
     'APIResource',
+    'SessionEndpoint',
     'SessionResource',
 ]
\ No newline at end of file
