@@ -60,8 +60,10 @@ class GoogleDatastoreRepository(ddd.Repository):
     def restore(self, entity: Entity | None) -> Any:
         if entity is None:
             return None
-        instance = self.model.parse_obj(entity)
-        setattr(instance, self.id_attr, entity.key.id) # type: ignore
+        instance = self.model.parse_obj({
+            **entity,
+            self.id_attr: entity.key.id # type: ignore
+        })
         return instance
 
     def storage_key(
